@@ -85,22 +85,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD),
     MAKE_ENTRY(NV_CTRL_GPU_MAX_CORE_THRESHOLD),
     MAKE_ENTRY(NV_CTRL_AMBIENT_TEMPERATURE),
-    MAKE_ENTRY(NV_CTRL_GVO_SUPPORTED),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_MODE),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_SOURCE),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVO_DATA_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE),
-    MAKE_ENTRY(NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED),
-    MAKE_ENTRY(NV_CTRL_GVO_VIDEO_OUTPUTS),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_DELAY_PIXELS),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_DELAY_LINES),
-    MAKE_ENTRY(NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_CLOCK_FREQS),
     MAKE_ENTRY(NV_CTRL_FLATPANEL_CHIP_LOCATION),
     MAKE_ENTRY(NV_CTRL_FLATPANEL_LINK),
@@ -112,16 +96,10 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_XINERAMA),
     MAKE_ENTRY(NV_CTRL_XINERAMA_STEREO),
     MAKE_ENTRY(NV_CTRL_BUS_RATE),
-    MAKE_ENTRY(NV_CTRL_SHOW_SLI_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT2),
-    MAKE_ENTRY(NV_CTRL_GVO_OVERRIDE_HW_CSC),
-    MAKE_ENTRY(NV_CTRL_GVO_CAPABILITIES),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_TERMINATION),
     MAKE_ENTRY(NV_CTRL_PROBE_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_REFRESH_RATE),
-    MAKE_ENTRY(NV_CTRL_GVO_FLIP_QUEUE_SIZE),
     MAKE_ENTRY(NV_CTRL_CURRENT_SCANLINE),
     MAKE_ENTRY(NV_CTRL_INITIAL_PIXMAP_PLACEMENT),
     MAKE_ENTRY(NV_CTRL_PCI_BUS),
@@ -135,7 +113,6 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_MULTIGPU_DISPLAY_OWNER),
     MAKE_ENTRY(NV_CTRL_FSAA_APPLICATION_ENHANCED),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_RATE_4),
-    MAKE_ENTRY(NV_CTRL_GVO_LOCK_OWNER),
     MAKE_ENTRY(NV_CTRL_HWOVERLAY),
     MAKE_ENTRY(NV_CTRL_NUM_GPU_ERRORS_RECOVERED),
     MAKE_ENTRY(NV_CTRL_REFRESH_RATE_3),
@@ -143,45 +120,19 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_GLYPH_CACHE),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PERFORMANCE_LEVEL),
     MAKE_ENTRY(NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE),
-    MAKE_ENTRY(NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_LOCK_STATUS),
-    MAKE_ENTRY(NV_CTRL_GVO_ANC_TIME_CODE_GENERATION),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_ALPHA_KEY),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_LUMA_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_CR_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_CB_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES),
     MAKE_ENTRY(NV_CTRL_DEPTH_30_ALLOWED),
     MAKE_ENTRY(NV_CTRL_MODE_SET_EVENT),
     MAKE_ENTRY(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE),
-    MAKE_ENTRY(NV_CTRL_VCSC_HIGH_PERF_MODE),
     MAKE_ENTRY(NV_CTRL_DISPLAYPORT_LINK_RATE),
     MAKE_ENTRY(NV_CTRL_STEREO_EYES_EXCHANGE),
     MAKE_ENTRY(NV_CTRL_NO_SCANOUT),
-    MAKE_ENTRY(NV_CTRL_GVO_CSC_CHANGED_EVENT),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_TO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_X_SERVER_UNIQUE_ID),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB),
-    MAKE_ENTRY(NV_CTRL_IS_GVO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_PCI_ID),
-    MAKE_ENTRY(NV_CTRL_GVO_FULL_RANGE_COLOR),
     MAKE_ENTRY(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE),
-    MAKE_ENTRY(NV_CTRL_GVO_ENABLE_RGB_DATA),
     MAKE_ENTRY(NV_CTRL_IMAGE_SHARPENING_DEFAULT),
     MAKE_ENTRY(NV_CTRL_PCI_DOMAIN),
-    MAKE_ENTRY(NV_CTRL_GVI_NUM_JACKS),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_LINKS_PER_STREAM),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER),
-    MAKE_ENTRY(NV_CTRL_GVI_GLOBAL_IDENTIFIER),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION),
     MAKE_ENTRY(NV_CTRL_GPU_COOLER_MANUAL_CONTROL),
     MAKE_ENTRY(NV_CTRL_THERMAL_COOLER_LEVEL),
@@ -199,17 +150,10 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS),
     MAKE_ENTRY(NV_CTRL_GPU_ECC_RESET_ERROR_STATUS),
     MAKE_ENTRY(NV_CTRL_GPU_POWER_MIZER_MODE),
-    MAKE_ENTRY(NV_CTRL_GVI_SYNC_OUTPUT_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_CHANNELS_PER_JACK),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_STREAMS),
-    MAKE_ENTRY(NV_CTRL_GVI_NUM_CAPTURE_SURFACES),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_GENERATION),
-    MAKE_ENTRY(NV_CTRL_GVI_BOUND_GPU),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT3),
     MAKE_ENTRY(NV_CTRL_ACCELERATE_TRAPEZOIDS),
     MAKE_ENTRY(NV_CTRL_GPU_CORES),
     MAKE_ENTRY(NV_CTRL_GPU_MEMORY_BUS_WIDTH),
-    MAKE_ENTRY(NV_CTRL_GVI_TEST_MODE),
     MAKE_ENTRY(NV_CTRL_COLOR_SPACE),
     MAKE_ENTRY(NV_CTRL_COLOR_RANGE),
     MAKE_ENTRY(NV_CTRL_DITHERING_MODE),
@@ -218,9 +162,7 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_READING),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_PROVIDER),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_TARGET),
-    MAKE_ENTRY(NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL),
@@ -238,12 +180,10 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_SYNC_CYCLE),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_MISSED_SYNC_CYCLES),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_BATTERY_LEVEL),
-    MAKE_ENTRY(NV_CTRL_GVO_ANC_PARITY_COMPUTATION),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_PAIR_EVENT),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_UNPAIR_EVENT),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_CURRENT_LINK_WIDTH),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_CURRENT_LINK_SPEED),
-    MAKE_ENTRY(NV_CTRL_GVO_AUDIO_BLANKING),
     MAKE_ENTRY(NV_CTRL_CURRENT_METAMODE_ID),
     MAKE_ENTRY(NV_CTRL_DISPLAY_ENABLED),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_INCOMING_HOUSE_SYNC_RATE),
@@ -286,21 +226,12 @@ static const char *attr_str_table[NV_CTRL_STRING_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_STRING_VBIOS_VERSION),
     MAKE_ENTRY(NV_CTRL_STRING_NVIDIA_DRIVER_VERSION),
     MAKE_ENTRY(NV_CTRL_STRING_DISPLAY_DEVICE_NAME),
-    MAKE_ENTRY(NV_CTRL_STRING_GVIO_FIRMWARE_VERSION),
     MAKE_ENTRY(NV_CTRL_STRING_CURRENT_MODELINE),
     MAKE_ENTRY(NV_CTRL_STRING_ADD_MODELINE),
     MAKE_ENTRY(NV_CTRL_STRING_DELETE_MODELINE),
     MAKE_ENTRY(NV_CTRL_STRING_CURRENT_METAMODE),
     MAKE_ENTRY(NV_CTRL_STRING_ADD_METAMODE),
     MAKE_ENTRY(NV_CTRL_STRING_DELETE_METAMODE),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_PRODUCT_NAME),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_PRODUCT_ID),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_SERIAL_NUMBER),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_BUILD_DATE),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_FIRMWARE_VERSION),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_FIRMWARE_REVISION),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_HARDWARE_VERSION),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_HARDWARE_REVISION),
     MAKE_ENTRY(NV_CTRL_STRING_MOVE_METAMODE),
     MAKE_ENTRY(NV_CTRL_STRING_VALID_HORIZ_SYNC_RANGES),
     MAKE_ENTRY(NV_CTRL_STRING_VALID_VERT_REFRESH_RANGES),
@@ -308,10 +239,6 @@ static const char *attr_str_table[NV_CTRL_STRING_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER),
     MAKE_ENTRY(NV_CTRL_STRING_SLI_MODE),
     MAKE_ENTRY(NV_CTRL_STRING_PERFORMANCE_MODES),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_FAN_STATUS),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_TEMPERATURES),
-    MAKE_ENTRY(NV_CTRL_STRING_VCSC_PSU_INFO),
-    MAKE_ENTRY(NV_CTRL_STRING_GVIO_VIDEO_FORMAT_NAME),
     MAKE_ENTRY(NV_CTRL_STRING_GPU_CURRENT_CLOCK_FREQS),
     MAKE_ENTRY(NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_HARDWARE_REVISION),
     MAKE_ENTRY(NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_VERSION_A),
@@ -345,8 +272,6 @@ static const char *attr_bin_table[NV_CTRL_BINARY_DATA_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_GPUS_USING_FRAMELOCK),
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_DISPLAY_VIEWPORT),
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU),
-    MAKE_ENTRY(NV_CTRL_BINARY_DATA_GPUS_USING_VCSC),
-    MAKE_ENTRY(NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU),
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU),
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN),
     MAKE_ENTRY(NV_CTRL_BINARY_DATA_THERMAL_SENSORS_USED_BY_GPU),
@@ -366,7 +291,6 @@ static const char *attr_strop_table[NV_CTRL_STRING_OPERATION_LAST_ATTRIBUTE + 1]
     MAKE_ENTRY(NV_CTRL_STRING_OPERATION_GTF_MODELINE),
     MAKE_ENTRY(NV_CTRL_STRING_OPERATION_CVT_MODELINE),
     MAKE_ENTRY(NV_CTRL_STRING_OPERATION_BUILD_MODEPOOL),
-    MAKE_ENTRY(NV_CTRL_STRING_OPERATION_GVI_CONFIGURE_STREAMS),
     MAKE_ENTRY(NV_CTRL_STRING_OPERATION_PARSE_METAMODE),
 };
 
@@ -380,8 +304,6 @@ static void print_perms(NVCTRLAttributePermissionsRec *perms)
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_FRAMELOCK)                 ? 'F' : '_');
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_X_SCREEN)                  ? 'X' : '_');
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_XINERAMA)                  ? 'I' : '_');
-    printf("%c", (perms->permissions & ATTRIBUTE_TYPE_VCSC)                      ? 'V' : '_');
-    printf("%c", (perms->permissions & ATTRIBUTE_TYPE_GVI)                       ? 'S' : '_');
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_COOLER)                    ? 'C' : '_');
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_THERMAL_SENSOR)            ? 'T' : '_');
     printf("%c", (perms->permissions & ATTRIBUTE_TYPE_3D_VISION_PRO_TRANSCEIVER) ? '3' : '_');
@@ -421,7 +343,7 @@ static void print_table_entry(NVCTRLAttributePermissionsRec *perms,
      * and the attribute table was missing an entry for the attribute.
      * Either condition by itself is acceptable:
      *
-     * - Event-only attributes (e.g., NV_CTRL_GVO_CSC_CHANGED_EVENT)
+     * - Event-only attributes (e.g., NV_CTRL_MODE_SET_EVENT)
      *   don't have any permissions.
      *
      * - A missing table entry could just mean the table is stale
